@@ -1,5 +1,9 @@
 #!/usr/bin/env python
-"""Tests for `ssh2_parse_key` package - load private keys."""
+"""
+Tests for `ssh2_parse_key` package - load private keys.
+
+Loads the private keys.  This causes exceptions to be raised.
+"""
 import pytest
 
 from ssh2_parse_key import Ssh2Key
